============
Installation
============

**Install required packages**


Minimum version requirements:

    qemu >= 2.1

    libvirt >= 1.2.10



Fedora::

    yum install -y kernel-headers kernel-core kernel-modules kernel kernel-devel kernel-modules-extra

